@@ -750,6 +750,7 @@ class ContextService():
 
     def get_hierachy_paths(self, context, key=None, path_prefix=None, ignore_stage=False, uninherited=False, reverse=False):
         result = []
+        if path_prefix.endswith('/'): path_prefix = path_prefix[:-1]
         if uninherited:
             result.append(path_prefix + context.get_path(key))
         else:
@@ -760,7 +761,7 @@ class ContextService():
                 result.append(path_prefix + Context(context.namespace, 'default', 'default', Stages.get_default_env(context.stage)).get_path(key))
                 ### Add global numbered stage context
                 if not Stages.is_default_env(context.stage):
-                    result.append(path_prefix + Context(context.namespace, 'default', 'default', stage).get_path(key))
+                    result.append(path_prefix + Context(context.namespace, 'default', 'default', context.stage).get_path(key))
 
             if not context.project == 'default':
                 ### Add the project context: /project/default/default/0
@@ -770,7 +771,7 @@ class ContextService():
                     result.append(path_prefix + Context(context.namespace, context.project, 'default', Stages.get_default_env(context.stage)).get_path(key))
                     ### Add the project numbered stage context: /project/default/stage/env
                     if not Stages.is_default_env(context.stage):
-                        result.append(path_prefix + Context(context.namespace, context.project, 'default', stage).get_path(key))
+                        result.append(path_prefix + Context(context.namespace, context.project, 'default', context.stage).get_path(key))
                 
                 if not context.application == 'default':
                     ### Add the application context: /project/application/default/0
@@ -785,5 +786,4 @@ class ContextService():
         return list(reversed(result)) if reverse else result
 
 
-
 Contexts = ContextService()
\ No newline at end of file
