@@ -5,7 +5,7 @@ MAC_PLATFORM = platform.system() == 'Darwin'
 NIX_PLATFORM = platform.system() == 'Linux'
 
 COLORED_LOGS = os.getenv('DSO_COLORED_LOGS', 'Yes').lower() in ['yes', 'true']
-BOLD_LOGS = os.getenv('DSO_BOLD_LOGS', 'Yes').lower() in ['yes', 'true']
+BOLD_LOGS = os.getenv('DSO_BOLD_LOGS', 'No').lower() in ['yes', 'True']
 TIMESTAMP_LOGS = os.getenv('DSO_TIMESTAMP_LOGS', 'Yes').lower() in ['yes', 'true']
 LABEL_LOG_LEVELS = os.getenv('DSO_LABEL_LOG_LEVELS', 'Yes').lower() in ['yes', 'true']
 USE_PAGER = os.getenv('DSO_USE_PAGER', 'Yes').lower() in ['yes', 'true']
